==> bcprov-jdk15on-1.50-sources.jar: org/bouncycastle/LICENSE.java <==
package org.bouncycastle;

/**
 * The Bouncy Castle License
 *
 * Copyright (c) 2000-2013 The Legion Of The Bouncy Castle (http://www.bouncycastle.org)
 * <p>
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software 
 * and associated documentation files (the "Software"), to deal in the Software without restriction, 
 * including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 * <p>
 * The above copyright notice and this permission notice shall be included in all copies or substantial
 * portions of the Software.
 * <p>
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
public class LICENSE
{
    public static String licenseText =
      "Copyright (c) 2000-2013 The Legion of the Bouncy Castle Inc. (http://www.bouncycastle.org) "
      + System.getProperty("line.separator")
      + System.getProperty("line.separator")
      + "Permission is hereby granted, free of charge, to any person obtaining a copy of this software "
      + System.getProperty("line.separator")
      + "and associated documentation files (the \"Software\"), to deal in the Software without restriction, "
      + System.getProperty("line.separator")
      + "including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, "
      + System.getProperty("line.separator")
      + "and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so,"
      + System.getProperty("line.separator")
      + "subject to the following conditions:"
      + System.getProperty("line.separator")
      + System.getProperty("line.separator")
      + "The above copyright notice and this permission notice shall be included in all copies or substantial"
      + System.getProperty("line.separator")
      + "portions of the Software."
      + System.getProperty("line.separator")
      + System.getProperty("line.separator")
      + "THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,"
      + System.getProperty("line.separator")
      + "INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR"
      + System.getProperty("line.separator")
      + "PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE"
      + System.getProperty("line.separator")
      + "LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR"
      + System.getProperty("line.separator")
      + "OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER"
      + System.getProperty("line.separator")
      + "DEALINGS IN THE SOFTWARE.";

    public static void main(
        String[]    args)
    {
        System.out.println(licenseText);
    }
}

==> bcprov-jdk15on-1.55-sources.jar: org/bouncycastle/LICENSE.java <==
package org.bouncycastle;

import org.bouncycastle.util.Strings;

/**
 * The Bouncy Castle License
 *
 * Copyright (c) 2000-2015 The Legion Of The Bouncy Castle Inc. (http://www.bouncycastle.org)
 * <p>
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software 
 * and associated documentation files (the "Software"), to deal in the Software without restriction, 
 * including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, 
 * and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 * <p>
 * The above copyright notice and this permission notice shall be included in all copies or substantial
 * portions of the Software.
 * <p>
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */
public class LICENSE
{
    public static String licenseText =
      "Copyright (c) 2000-2015 The Legion of the Bouncy Castle Inc. (http://www.bouncycastle.org) "
      + Strings.lineSeparator()
      + Strings.lineSeparator()
      + "Permission is hereby granted, free of charge, to any person obtaining a copy of this software "
      + Strings.lineSeparator()
      + "and associated documentation files (the \"Software\"), to deal in the Software without restriction, "
      + Strings.lineSeparator()
      + "including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, "
      + Strings.lineSeparator()
      + "and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so,"
      + Strings.lineSeparator()
      + "subject to the following conditions:"
      + Strings.lineSeparator()
      + Strings.lineSeparator()
      + "The above copyright notice and this permission notice shall be included in all copies or substantial"
      + Strings.lineSeparator()
      + "portions of the Software."
      + Strings.lineSeparator()
      + Strings.lineSeparator()
      + "THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,"
      + Strings.lineSeparator()
      + "INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR"
      + Strings.lineSeparator()
      + "PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE"
      + Strings.lineSeparator()
      + "LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR"
      + Strings.lineSeparator()
      + "OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER"
      + Strings.lineSeparator()
      + "DEALINGS IN THE SOFTWARE.";

    public static void main(
        String[]    args)
    {
        System.out.println(licenseText);
    }
}
